@@ -14,11 +14,12 @@ extern void *selfptr;
 extern void *textptr;
 extern int integer, commvar;
 
-int main(void) {
+int main(void)
+{
 
     printf("Testing lrotate: should get 0x00400000, 0x00000001\n");
-    printf("lrotate(0x00040000, 4) = 0x%08lx\n", lrotate(0x40000,4));
-    printf("lrotate(0x00040000, 14) = 0x%08lx\n", lrotate(0x40000,14));
+    printf("lrotate(0x00040000, 4) = 0x%08lx\n", lrotate(0x40000, 4));
+    printf("lrotate(0x00040000, 14) = 0x%08lx\n", lrotate(0x40000, 14));
 
     printf("This string should read `hello, world': `%s'\n", asmstr);
 
@@ -27,8 +28,7 @@ int main(void) {
     commvar = 4321;
     greet();
 
-    printf("These pointers should be equal: %p and %p\n",
-	   &greet, textptr);
+    printf("These pointers should be equal: %p and %p\n", &greet, textptr);
 
     printf("So should these: %p and %p\n", selfptr, &selfptr);
 }
